# Offline human review

## 1. Critical
- [4] Group 1:
    - Remove AI slops like 'let's be blunt,' 'painfully obvious,' and 'cut through the hype'.
    - Avoid marketing-y or purple-prose phrasing. Specifically avoid:
      - "let's be blunt", "painfully obvious", "cut through the hype"
      - "embracing" and its derivatives
      - "crucial", "paramount", "invaluable", "significant", "dramatically", "seamlessly"
      - "leverage", "fast-moving world (of AI)", "But here's the good news"
      - "this is where X comes in"
      - "imagine …" openings
      - "is more than a …" constructions (e.g., "X is more than a …; it's …")
      - "In the early days …", "These aren't just theoretical problems; they are …"
    - Don't use the word "embracing" and its derivatives, it's AI slop.
    - Don't use the word "crucial" and its derivatives, it's AI slop.
    - When making examples, replace "imagine we have ..." with "suppose we have ...".

## 2. Important
- [2] Group 2:
    - Intro: mention the lessons where ReAct was mentionned, like in lesson 02 where it was mentionned, here the lesson seems to be written in isolation
    - it seems as if the big research labs are moving towards building ReAct type agents (due to better reasoning models), it could be mentionned somewhere, e.g. gemini cli, chatgpt agent

## 3. Minor
- [1] Group 3:
    - Do not start the first paragarph with "To understand the problem...". It seems very abrupt.
- [1] Group 4:
    - Do not use the "—" character; use a standard hyphen.
- [1] Group 5:
    - Prefer concise, skimmable sentences; avoid paragraphs that pack multiple key ideas.

## ! Clashing

## Legend

A group is formatted as follows:
"[<frequency_number>] Group <group_number>:
    - <review>
    - <review>
    - ...
"